### Name: SVMBench
### Title: SVM Benchmarking Data and Consensus Relations
### Aliases: SVM_Benchmarking_Classification SVM_Benchmarking_Regression
###   SVM_Benchmarking_Classification_Consensus
###   SVM_Benchmarking_Regression_Consensus
### Keywords: datasets

### ** Examples

data("SVM_Benchmarking_Classification")

## 21 data sets
names(SVM_Benchmarking_Classification)

## 17 methods
relation_domain(SVM_Benchmarking_Classification)

## select preferences
preferences <-
    Filter(relation_is_preference, SVM_Benchmarking_Classification)

## only the artifical data sets yield preferences
names(preferences)

## visualize them using Hasse diagrams
if(require("Rgraphviz")) plot(preferences)

## Same for regression:
data("SVM_Benchmarking_Regression")

## 12 data sets
names(SVM_Benchmarking_Regression)

## 10 methods
relation_domain(SVM_Benchmarking_Regression)

## select preferences
preferences <-
    Filter(relation_is_preference, SVM_Benchmarking_Regression)

## only two of the artifical data sets yield preferences
names(preferences)

## visualize them using Hasse diagrams
if(require("Rgraphviz")) plot(preferences)

## Consensus solutions:

data("SVM_Benchmarking_Classification_Consensus")
data("SVM_Benchmarking_Regression_Consensus")

## The solutions for the three families are not unique
print(SVM_Benchmarking_Classification_Consensus)
print(SVM_Benchmarking_Regression_Consensus)

## visualize the consensus preferences
classP <- SVM_Benchmarking_Classification_Consensus$P
regrP <- SVM_Benchmarking_Regression_Consensus$P
if(require("Rgraphviz")) {
    plot(classP)
    plot(regrP)
}

## in tabular style:
ranking <- function(x) rev(names(sort(relation_class_ids(x))))
sapply(classP, ranking)
sapply(regrP, ranking)

## (prettier and more informative:)
relation_classes(classP[[1L]])



